<?

//Funkcja pobiera certyfikat CA z serwera LDAP
function get_ca_crt() {
	$ca_ldap = $GLOBALS['PKI_config']['ca_ldap'];
        $base = $GLOBALS['PKI_config']['ca_basedn'];
        $filter = $GLOBALS['PKI_config']['ca_filter'];
	$ds=ldap_connect($ca_ldap);  
	if ($ds) { 
	   $r=ldap_bind($ds);     
	   $sr=ldap_search($ds, $base, $filter); 
	   $entry = ldap_first_entry($ds, $sr);
	   $values = ldap_get_values_len($ds, $entry,"cACertificate;binary");
	   $cacert = $values[0];
	}
	ldap_close($ds);
	return($cacert);
}

//Funkcja pobiera CRL z serwera LDAP
function get_ca_crl() {
	$ca_ldap=$GLOBALS['PKI_config']['ca_ldap'];
        $base = $GLOBALS['PKI_config']['ca_basedn'];
        $filter = $GLOBALS['PKI_config']['ca_filter'];
	$ds=ldap_connect($ca_ldap);  
	if ($ds) {
	   $r=ldap_bind($ds);     
	   $sr=ldap_search($ds, $base, $filter); // Search entry
	   $entry = ldap_first_entry($ds, $sr);
	   $values = ldap_get_values_len($ds, $entry,"certificateRevocationList;binary");
	   $crl = $values[0];
	}
	ldap_close($ds);
	return($crl);
}

//Funkcja konwersji formatu binarnego na format PEM
function b2pem($cert) {
	$pem="-----BEGIN CERTIFICATE-----\n" .
	str_replace(" ","+",chunk_split($cert,64,"\n")) .
	"-----END CERTIFICATE-----\n";
	return $pem;
}

//Funkcja wywoluje komende systemowa
function execute($cmd,$stdin) {
	$pipe = popen("$cmd << EOT \n$stdin\nEOT\n", 'r');
	$output= '';
	while($s = fgets($pipe, 1024)) {
		$output .= $s;
	}
	pclose($pipe);
	return $output;
}

//Funkcja zwraca adres e-mail z podanego certyfikatu
function get_crt_email($crt) {
	$cmd=$GLOBALS['PKI_config']['ssl_path'] ." x509 -inform PEM -noout -email" ;
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	return str_replace("\n","",$output);
}

//Funkcja weryfikuje zgodnosc certyfikatu z CA
function verify_crt_chain($crt) {
        $cmd=$GLOBALS['PKI_config']['ssl_path'] . " verify";
        if (isset($GLOBALS['PKI_config']['ssl_CAfile'])) $cmd .= " -CAfile " . $GLOBALS['PKI_config']['ssl_CAfile'];
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	return strstr($output,"OK");
}

//Funkcja weryfikuje waznosc certyfikatu
function verify_crt($crt) {
	$cmd=$GLOBALS['PKI_config']['ssl_path'] . " verify";
        if (isset($GLOBALS['PKI_config']['ssl_CAfile'])) $cmd .= " -CAfile " . $GLOBALS['PKI_config']['ssl_CAfile'];
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	if (strstr($output,"error")) {
            return FALSE;
        }
	return strstr($output,"OK");
}

//Funkcja zwraca numer seryjny certyfikatu
function get_crt_serial($crt) {
	$cmd= $GLOBALS['PKI_config']['ssl_path'] . " x509 -inform PEM -noout -serial";
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	return str_replace("serial=","",$output);	
}

//Funkcja zwraca date rozpoczecia okresu waznosci podanego certyfikatu
function get_crt_date_from($crt) {
	$cmd=$GLOBALS['PKI_config']['ssl_path'] ." x509 -inform PEM -noout -startdate";
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	return str_replace("notBefore=","",$output);
}

//Funkcja zwraca date zakonczenia okresu waznosci podanego certyfikatu
function get_crt_date_to($crt) {
	$cmd=$GLOBALS['PKI_config']['ssl_path'] ." x509 -inform PEM -noout -enddate";
	$pem=b2pem($crt);
	$output=execute($cmd,$pem);
	return str_replace("notAfter=","",$output);
}

//Funkcja weryfikuje waznosc certyfikatu na bazie podanego CRL
function verify_crl($serial) {
	$cmd=$GLOBALS['PKI_config']['ssl_path'] ." crl -noout -text";
	$pem=get_ca_crl();
	$output=execute($cmd,$pem);
        if(!strstr($output,"Serial Number: $serial"))
	return strstr($output,"Serial Number: $serial");
}

?>
