<?php

# define actionID
$ActionID = array (
      'EXPAND FOLDER'   => 10,
      'COLLAPSE FOLDER' => 11,
      'COLLAPSE ALL'    => 12,
      'DISPLAY ENTRY'   => 13,
      'EXPAND DISPLAY'  => 14,
      'LOCALITY'        => 15,
      'GLOBAL SEARCH'   => 21,
      'SEARCH'          => 22,
      'DISPLAY RESULT'  => 23,
      'REPORT'          => 24,
      'DISPLAY REPORT'  => 25, 
      'CHANGE LANG'	=> 27,
      'SEARCH RESULT'   => 28,
      );

$Action = array_flip($ActionID);


function getParameters(){
   
   global $binddn, $password, $basedn, $server, $port;
   global $basedn_iso, $ldap_config, $language, $LANG;

   # check configuration and get settings
   if (isset($ldap_config['server']) && isset($ldap_config['basedn']) ){

      $basedn_iso = $ldap_config['basedn'];
      $basedn = iconv("ISO-8859-2","UTF-8", $ldap_config['basedn']);
      $server = $ldap_config['server'];
      if (isset($ldap_config['port'])) $port = $ldap_config['port'];
      else $port = 389;
   }
 
   else { 
       include  "./lib/error.inc";
       Error(NULL, $LANG['configure_error']);
   }

  ldap_set_option($ds,LDAP_OPT_PROTOCOL_VERSION,3);
  if (isset($ldap_config['binddn']) && isset($ldap_config['password'])) {
     $binddn = iconv("ISO-8859-2","UTF-8",$ldap_config['binddn']);
     $password = $ldap_config['password'];
  }
}

function ldap_init(){

global $server, $port, $binddn, $password, $ds, $local_config;
global $language, $LANG;

if (!($ds = @ldap_connect($server, $port))){
   include  "./lib/error.inc";
   Error(NULL, $LANG['connect_error']);
   return 1;
}

if (is_local_user()) {
  if ($local_config['binddn'] && $local_config['password']) {
     $binddn = iconv("ISO-8859-2","UTF-8", $local_config['binddn']);
     $password = $local_config['password'];
  }
}

if ($binddn && $password) {
    if (!(@ldap_bind($ds, $binddn, $password))){
      #if (!(@ldap_bind($ds))){
         include  "./lib/error.inc";
         ldapError($ds, ldap_errno($ds));
         return 1;
      #}
    }
}

else if (!(@ldap_bind($ds))){
      include  "./lib/error.inc";
      ldapError($ds, ldap_errno($ds));
      return 1;
}
return 0;
}

function is_local_user(){

global $local_config;
if (isset($_SESSION['lOcAlUsEr'])){
   if ($_SESSION['lOcAlUsEr'] == 1) return 1;
   else return 0;  
}
return 0;
}


function display_link($Action, $modul, $dn){

global $ActionID;

echo $modul . ".php?actionID=" . $ActionID[$Action]. "&dn=" .urlencode($dn);
}


function is_Unit($attrs){

foreach ($attrs as $value){
   if (strcasecmp($value, "organizationalUnit") == 0)  return true;
   if (strcasecmp($value, "organization") == 0)  return true;
   if (strcasecmp($value, "country") == 0)  return true;
}
return false;
}

function is_Role($attrs){

foreach ($attrs as $value){
   if (strcasecmp($value, "organizationalRole") == 0)  return true;
}
return false;
}

function is_Person($attrs){

foreach ($attrs as $value){
   if (strcasecmp($value, "Person") == 0)  return true;
}
return false;
}


function getDisplayName($dn,$entry,$lang){

   if (isset($entry['displayname;lang-'.$lang])) {
      $name = $entry['displayname;lang-'.$lang][0];
   }
   elseif (isset($entry['displayname'])) {
      $name = $entry['displayname'][0];
   }
   else {

      # take rdn
      $rdns = explodeDN ($dn,1);
      $rdn = explode("=", $rdns[0]);

      if (isset($entry[$rdn[0].";lang-".$lang])) {
         $name = $entry[$rdn[0].";lang-".$lang][0];
      }
      elseif(isset($entry[$rdn[0]])) {
         $name = $entry[$rdn[0]][0];
      }
      else {
         $name = $rdn[1];
      }
   }

   $name = iconv("UTF-8","ISO-8859-2",$name);

   if ($lang != 'pl') $name = strtr($name, "ʣӦ󶼿", "ACELNOSZZacelnoszz");

   $trans = array('\2C' => ",");
   $name = strtr($name, $trans);

   return $name;
}

function getSurname($entry,$lang){

   $dn = $entry['dn'];   
   if (isset($entry['displayname;lang-'.$lang])) {
      $cn = $entry['displayname;lang-'.$lang][0];
   }
   elseif (isset($entry['displayname'])) {
      $cn = $entry['displayname'][0];
   }
   else {
      $rdns = explodeDN($dn,0);
      $cn = $rdns[1];
   }
   $comp = preg_split("/\s+/", $cn);
   $sn = $comp[count($comp)-1];
   $sn = iconv("UTF-8","ISO-8859-2",$sn);
   if ($lang != 'pl') $sn = strtr($sn, "ʣӦ󶼿", "ACELNOSZZacelnoszz");

   return $sn;
}  

function  sortPL($a,$b){

   $aa = preg_split('//',$a);
   $bb = preg_split('//',$b);

   $tab = array('A','','B','C','','D','E','','F','G','H','I','J','K','L','','M',
                'N','','O','','P','Q','R','S','','T','U','W','X','Y','Z','','',
                'a','','b','c','','d','e','','f','g','h','i','j','k','l','','m',
                'n','','o','','p','q','r','s','','t','u','w','x','y','z','','');

   $tab = array_flip($tab);

   while (count($aa) >0 && count($bb)>0 && strcmp($aa[0],$bb[0]) == 0) {
      array_shift($aa);
      array_shift($bb);
   }

   if(!(isset($tab[$aa[0]]) || isset($tab[$bb[0]]) )) {
      return strcmp($aa[0], $bb[0]);
   }

   if (!isset($tab[$aa[0]])) {
     return -1;
   }

   if (!isset($tab[$bb[0]])) {
    return 1;
   }

   if ($tab[$aa[0]] < $tab[$bb[0]]) return -1;
   elseif ($tab[$aa[0]] == $tab[$bb[0]]) return 0;
    else return 1;
}

function explodeDN($dn,$with_attrs=1){
   
   $res = array();
   $rdns = explode(",",$dn);
   $j=0; 

   for ($i=0; $i<count($rdns); $i++){
        
      $increase = 0;
      if (preg_match("/(\\\)$/", $rdns[$i]) && isset($rdns[$i+1])) {
          $tmp = $rdns[$i] . ",";    
      } 
      else {
          $tmp = $rdns[$i];
          $increase = 1;
      }

      if (isset($res[$j])) {
         $res[$j] .= $tmp;    
      } 
      else {
         if (preg_match("/^[-;\w]+=(.+)/",$tmp,$matches)) {        

            if ($with_attrs) {
               $res[$j] = $tmp; 
            }
            else {
               $res[$j] = $matches[1]; 
            }
         }
         else {
            $res = array();
            break;
         }
      }
      if ($increase) $j++;
   }
   return $res;
}


?>
